%define ALD_Ver		1.2.4

%define OrgName pkg-config

License:      GPL
Summary:      This is pkg-config
Group:        System Environment/Libraries
Version:      0.25
Release:      1025.0

Source: %{OrgName}-%{version}.tar.xz
Patch0: %{OrgName}-%{version}.patch
Patch1: %{OrgName}-%{version}.x86_64.patch
Patch2: %{OrgName}-%{version}.arm.patch

%define DestDir		/Embedded/uC-%{uC_Version}
%define uC_Version 1.0.25

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define USE_LOCAL_CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%define USE_LOCAL_CROSS 1
%define BUILD_LOCAL_CROSS 0
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
# -----------------------------------------------------
%if %{BUILD_LOCAL_CROSS}
Name:         uC-%{OrgName}-%{TO_ARCH}
%else
Name:         uC-%{OrgName}
%endif

%define _prefix /usr/uC/%{uC_Version}/static
%define _lib lib

#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
#ERROR: target=%{_os}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%if %{BUILD_LOCAL_CROSS}
%define _prefix		%{csysdir}/usr/uC/%{uC_Version}/static
%define CrossDestDir	/Cross
%else
%define CrossDestDir %{nil}
%endif

%if !%{BUILD_LOCAL_CROSS}
%define __os_install_post \
    %{csysbindir}/rpm/brp-strip \
    %{csysbindir}/rpm/brp-strip-static-archive \
    %{csysbindir}/rpm/brp-strip-comment-note \
    %{_rpmconfigdir}/brp-compress \
%{nil}
%endif #BUILD_LOCAL_CROSS

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir %{nil}
%define _srcrpmdir %{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-uclibc
%define target_  %{nil}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{OrgName}

# ------------------- description ------------------------------------
%description
pkg-config is a script to make putting together all the build
flags when compiling/linking a lot easier.
#-------------------------------
%package doc
Summary:      doc for %{name}
Group:        Documentation
%description doc
doc for %{name}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}
%patch0 -b .orig -p0
%if %{_CROSS}
%if %{_arch} == "x86_64"
%patch1 -b .orig -p0
%endif
%if %{_arch} == "arm"
%patch2 -b .orig -p0
%endif
%endif # _CROSS

# ------------------- Build ------------------------------------------
%Build
%if %{USE_LOCAL_CROSS} && !%{BUILD_LOCAL_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

GCC_VER_STR=`%{target_}gcc -dumpversion`

%if %{BUILD_LOCAL_CROSS}
%if %{_build_cpu} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if (%{_build_cpu} == "x86_64") || (%{_build_cpu} == "win64") 
OPTFLAGS="-Os"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if (%{_build_cpu} == "armv6l") || (%{_build_cpu} == "armv7l")
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
OPT47=
%endif
%else
%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
OPT47=
%endif
%endif

CFLAGS="$OPTFLAGS $OPT47 -ffunction-sections -fdata-sections -fno-stack-protector"
LDFLAGS="-Wl,--gc-sections"

%configure \
	--build=%{_build} \
%if %{_CROSS} && !%{BUILD_LOCAL_CROSS}
	--host=%{target} \
%endif
	--without-debug \
	--enable-debug=no \
	--with-pc-path=%{_prefix}/lib/pkgconfig:%{_prefix}/usr/share/pkgconfig \
	--enable-threads=no \
	--with-threads=none \
	&>FConfigure_log.txt

make &>FMake_log.txt


# ------------------- Install ----------------------------------------
%Install
%if %{USE_LOCAL_CROSS} && !%{BUILD_LOCAL_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
UCLIBC_GCC_INC_SKIP=%{csysdir}/usr/include
export PATH GCC_NoHostPath UCLIBC_GCC_INC_SKIP
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt
cp -a AUTHORS README $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING

pushd $RPM_BUILD_ROOT%{_bindir}
  ln -s pkg-config %{_arch}-uclibc-pkg-config
%if %{_CROSS} && %{BUILD_LOCAL_CROSS}
  ln -s pkg-config %{target}-pkg-config
%endif
popd

%if %{BUILD_LOCAL_CROSS}
rm -r $RPM_BUILD_ROOT%{_mandir}
%endif

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} -r %{DestDir} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

%if %{BUILD_LOCAL_CROSS}
  DE=%{version}-%{release}.%{_build_cpu}.rpm
  DD=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}
%else  #%{BUILD_LOCAL_CROSS}
  DE=%{version}-%{release}.%{TO_ARCH}.rpm
  DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{CrossDestDir}%{DestDir}
%endif #!%{BUILD_LOCAL_CROSS}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-doc-$SE $DD/%{name}-doc-$DE
popd

%if %{BUILD_TAR}
# --------------- build *.tgz ------------------------
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}
  mkdir -p $tmp
%if %{BUILD_LOCAL_CROSS}
  cp -r cross $tmp/
%else
  cp -r usr $tmp/
%endif
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_LOCAL_CROSS

# ------------------- Files ------------------------------------------
%files
%{_bindir}
%{_datadir}/aclocal
%{docdir}/AUTHORS
%{docdir}/COPYING
%{docdir}/README

%files doc
%{_mandir}
%{docdir}/pkg-config-guide.html
